==> cxf-testutils-2.0.12-sources.jar: org/apache/locator/types/ObjectFactory.java <==

package org.apache.locator.types;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.locator.types package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _EndpointNotExistFault_QNAME = new QName("http://apache.org/locator/types", "EndpointNotExistFault");
    private final static QName _DeregisterEndpointResponse_QNAME = new QName("http://apache.org/locator/types", "deregisterEndpointResponse");
    private final static QName _ListEndpoints_QNAME = new QName("http://apache.org/locator/types", "listEndpoints");
    private final static QName _RegisterEndpointResponse_QNAME = new QName("http://apache.org/locator/types", "registerEndpointResponse");
    private final static QName _DeregisterPeerManagerResponse_QNAME = new QName("http://apache.org/locator/types", "deregisterPeerManagerResponse");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.locator.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link LookupEndpointResponse }
     * 
     */
    public LookupEndpointResponse createLookupEndpointResponse() {
        return new LookupEndpointResponse();
    }

    /**
     * Create an instance of {@link EndpointNotExistFaultException }
     * 
     */
    public EndpointNotExistFaultException createEndpointNotExistFaultException() {
        return new EndpointNotExistFaultException();
    }

    /**
     * Create an instance of {@link EndpointIdentity }
     * 
     */
    public EndpointIdentity createEndpointIdentity() {
        return new EndpointIdentity();
    }

    /**
     * Create an instance of {@link RegisterPeerManagerResponse }
     * 
     */
    public RegisterPeerManagerResponse createRegisterPeerManagerResponse() {
        return new RegisterPeerManagerResponse();
    }

    /**
     * Create an instance of {@link org.apache.locator.types.QueryEndpointsResponse.Endpoint }
     * 
     */
    public org.apache.locator.types.QueryEndpointsResponse.Endpoint createQueryEndpointsResponseEndpoint() {
        return new org.apache.locator.types.QueryEndpointsResponse.Endpoint();
    }

    /**
     * Create an instance of {@link RegisterPeerManager }
     * 
     */
    public RegisterPeerManager createRegisterPeerManager() {
        return new RegisterPeerManager();
    }

    /**
     * Create an instance of {@link QueryEndpoints }
     * 
     */
    public QueryEndpoints createQueryEndpoints() {
        return new QueryEndpoints();
    }

    /**
     * Create an instance of {@link DeregisterPeerManager }
     * 
     */
    public DeregisterPeerManager createDeregisterPeerManager() {
        return new DeregisterPeerManager();
    }

    /**
     * Create an instance of {@link LookupEndpoint }
     * 
     */
    public LookupEndpoint createLookupEndpoint() {
        return new LookupEndpoint();
    }

    /**
     * Create an instance of {@link RegisterEndpoint }
     * 
     */
    public RegisterEndpoint createRegisterEndpoint() {
        return new RegisterEndpoint();
    }

    /**
     * Create an instance of {@link DeregisterEndpoint }
     * 
     */
    public DeregisterEndpoint createDeregisterEndpoint() {
        return new DeregisterEndpoint();
    }

    /**
     * Create an instance of {@link EmptyMessage }
     * 
     */
    public EmptyMessage createEmptyMessage() {
        return new EmptyMessage();
    }

    /**
     * Create an instance of {@link ListEndpointsResponse }
     * 
     */
    public ListEndpointsResponse createListEndpointsResponse() {
        return new ListEndpointsResponse();
    }

    /**
     * Create an instance of {@link QueryEndpointsResponse }
     * 
     */
    public QueryEndpointsResponse createQueryEndpointsResponse() {
        return new QueryEndpointsResponse();
    }

    /**
     * Create an instance of {@link org.apache.locator.types.ListEndpointsResponse.Endpoint }
     * 
     */
    public org.apache.locator.types.ListEndpointsResponse.Endpoint createListEndpointsResponseEndpoint() {
        return new org.apache.locator.types.ListEndpointsResponse.Endpoint();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EndpointNotExistFaultException }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://apache.org/locator/types", name = "EndpointNotExistFault")
    public JAXBElement<EndpointNotExistFaultException> createEndpointNotExistFault(EndpointNotExistFaultException value) {
        return new JAXBElement<EndpointNotExistFaultException>(_EndpointNotExistFault_QNAME, EndpointNotExistFaultException.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EmptyMessage }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://apache.org/locator/types", name = "deregisterEndpointResponse")
    public JAXBElement<EmptyMessage> createDeregisterEndpointResponse(EmptyMessage value) {
        return new JAXBElement<EmptyMessage>(_DeregisterEndpointResponse_QNAME, EmptyMessage.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EmptyMessage }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://apache.org/locator/types", name = "listEndpoints")
    public JAXBElement<EmptyMessage> createListEndpoints(EmptyMessage value) {
        return new JAXBElement<EmptyMessage>(_ListEndpoints_QNAME, EmptyMessage.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EmptyMessage }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://apache.org/locator/types", name = "registerEndpointResponse")
    public JAXBElement<EmptyMessage> createRegisterEndpointResponse(EmptyMessage value) {
        return new JAXBElement<EmptyMessage>(_RegisterEndpointResponse_QNAME, EmptyMessage.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EmptyMessage }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://apache.org/locator/types", name = "deregisterPeerManagerResponse")
    public JAXBElement<EmptyMessage> createDeregisterPeerManagerResponse(EmptyMessage value) {
        return new JAXBElement<EmptyMessage>(_DeregisterPeerManagerResponse_QNAME, EmptyMessage.class, null, value);
    }

}

==> cxf-testutils-2.1-sources.jar: org/apache/locator/types/ObjectFactory.java <==

package org.apache.locator.types;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.locator.types package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _ListEndpoints_QNAME = new QName("http://apache.org/locator/types", "listEndpoints");
    private final static QName _EndpointNotExistFault_QNAME = new QName("http://apache.org/locator/types", "EndpointNotExistFault");
    private final static QName _RegisterEndpointResponse_QNAME = new QName("http://apache.org/locator/types", "registerEndpointResponse");
    private final static QName _DeregisterEndpointResponse_QNAME = new QName("http://apache.org/locator/types", "deregisterEndpointResponse");
    private final static QName _DeregisterPeerManagerResponse_QNAME = new QName("http://apache.org/locator/types", "deregisterPeerManagerResponse");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.locator.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link LookupEndpointResponse }
     * 
     */
    public LookupEndpointResponse createLookupEndpointResponse() {
        return new LookupEndpointResponse();
    }

    /**
     * Create an instance of {@link QueryEndpointsResponse.Endpoint }
     * 
     */
    public QueryEndpointsResponse.Endpoint createQueryEndpointsResponseEndpoint() {
        return new QueryEndpointsResponse.Endpoint();
    }

    /**
     * Create an instance of {@link ListEndpointsResponse.Endpoint }
     * 
     */
    public ListEndpointsResponse.Endpoint createListEndpointsResponseEndpoint() {
        return new ListEndpointsResponse.Endpoint();
    }

    /**
     * Create an instance of {@link DeregisterEndpoint }
     * 
     */
    public DeregisterEndpoint createDeregisterEndpoint() {
        return new DeregisterEndpoint();
    }

    /**
     * Create an instance of {@link EndpointIdentity }
     * 
     */
    public EndpointIdentity createEndpointIdentity() {
        return new EndpointIdentity();
    }

    /**
     * Create an instance of {@link RegisterPeerManager }
     * 
     */
    public RegisterPeerManager createRegisterPeerManager() {
        return new RegisterPeerManager();
    }

    /**
     * Create an instance of {@link RegisterPeerManagerResponse }
     * 
     */
    public RegisterPeerManagerResponse createRegisterPeerManagerResponse() {
        return new RegisterPeerManagerResponse();
    }

    /**
     * Create an instance of {@link QueryEndpoints }
     * 
     */
    public QueryEndpoints createQueryEndpoints() {
        return new QueryEndpoints();
    }

    /**
     * Create an instance of {@link EndpointNotExistFaultException }
     * 
     */
    public EndpointNotExistFaultException createEndpointNotExistFaultException() {
        return new EndpointNotExistFaultException();
    }

    /**
     * Create an instance of {@link EmptyMessage }
     * 
     */
    public EmptyMessage createEmptyMessage() {
        return new EmptyMessage();
    }

    /**
     * Create an instance of {@link RegisterEndpoint }
     * 
     */
    public RegisterEndpoint createRegisterEndpoint() {
        return new RegisterEndpoint();
    }

    /**
     * Create an instance of {@link ListEndpointsResponse }
     * 
     */
    public ListEndpointsResponse createListEndpointsResponse() {
        return new ListEndpointsResponse();
    }

    /**
     * Create an instance of {@link LookupEndpoint }
     * 
     */
    public LookupEndpoint createLookupEndpoint() {
        return new LookupEndpoint();
    }

    /**
     * Create an instance of {@link QueryEndpointsResponse }
     * 
     */
    public QueryEndpointsResponse createQueryEndpointsResponse() {
        return new QueryEndpointsResponse();
    }

    /**
     * Create an instance of {@link DeregisterPeerManager }
     * 
     */
    public DeregisterPeerManager createDeregisterPeerManager() {
        return new DeregisterPeerManager();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EmptyMessage }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://apache.org/locator/types", name = "listEndpoints")
    public JAXBElement<EmptyMessage> createListEndpoints(EmptyMessage value) {
        return new JAXBElement<EmptyMessage>(_ListEndpoints_QNAME, EmptyMessage.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EndpointNotExistFaultException }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://apache.org/locator/types", name = "EndpointNotExistFault")
    public JAXBElement<EndpointNotExistFaultException> createEndpointNotExistFault(EndpointNotExistFaultException value) {
        return new JAXBElement<EndpointNotExistFaultException>(_EndpointNotExistFault_QNAME, EndpointNotExistFaultException.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EmptyMessage }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://apache.org/locator/types", name = "registerEndpointResponse")
    public JAXBElement<EmptyMessage> createRegisterEndpointResponse(EmptyMessage value) {
        return new JAXBElement<EmptyMessage>(_RegisterEndpointResponse_QNAME, EmptyMessage.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EmptyMessage }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://apache.org/locator/types", name = "deregisterEndpointResponse")
    public JAXBElement<EmptyMessage> createDeregisterEndpointResponse(EmptyMessage value) {
        return new JAXBElement<EmptyMessage>(_DeregisterEndpointResponse_QNAME, EmptyMessage.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EmptyMessage }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://apache.org/locator/types", name = "deregisterPeerManagerResponse")
    public JAXBElement<EmptyMessage> createDeregisterPeerManagerResponse(EmptyMessage value) {
        return new JAXBElement<EmptyMessage>(_DeregisterPeerManagerResponse_QNAME, EmptyMessage.class, null, value);
    }

}
